""
Convenience module for importing {xschema}.

This allows users to import the library in two ways:
1. import exonware.{xschema}
2. import {xschema}  # This convenience import

Company: eXonware.com
Author: Eng. Muhammad AlShehri
Email: connect@exonware.com
Version: 0.0.1.2
Generation Date: February 2, 2025
""

# Import everything from the main package
from exonware.xschema import *  # noqa: F401, F403

# Preserve the version
__version__ = "0.0.1"